#!/bin/bash

# Check are you root?
echo "****************************************"
echo "   ShenZhen KeetouchUSB TouchScreen Install"
echo "****************************************"
echo ""

whoami | egrep "^root$" >/dev/null

if [ $? -ne 0 ]; then
  echo "Warning: You are not root!"
  echo "         Installation Failed!"
  exit
fi

echo "Show some information and check them!"

# Check what kind of the X Server is!
if [ -f /var/log/Xorg.0.log ]; then
  PATH_XServerConfig=$(egrep "Using config file" /var/log/Xorg.0.log|cut -d" " -f5|cut -d\" -f2)
  echo "X Window Config is in $PATH_XServerConfig"
  PATH_XServerModule=/usr/lib/xorg/modules
  echo "X Window Module Path is in $PATH_XServerModule"
else
  echo "Warning: Don't know where is your X Server config file."
  echo "         Installation Failed!"
  exit
fi

# I want to know where is your path!
echo $0 | egrep ^/ >/dev/null
if [ $? == 0 ]; then
  INSTALL_PATH=${0%/*}
else
  INSTALL_PATH=${PWD}/${0%/*}
fi

# the file is main file that I want to change!
TARGET_FILE=$PATH_XServerConfig

# Start to install
mkdir /etc/ktusb

cp -f "$INSTALL_PATH"/evtouch_drv.so "$PATH_XServerModule"/input

echo "Add touch configuration into $PATH_XServerConfig."
#sed -i '/ServerLayout/a\\t#InputDevice\t"kt" "SendCoreEvents"' $PATH_XServerConfig
filelines=`cat $PATH_XServerConfig | wc -l`
sed -i ''${filelines}'a\### KT Configuration Begin ###\
Section "ServerLayout"\
	Identifier    "XFree86 Configured"\
	Screen      0    "Default Screen"    0 0\
	InputDevice    "kt"\
EndSection\
### KT Configuration End ###' $PATH_XServerConfig


filelines=`cat $PATH_XServerConfig | wc -l`
sed -i ''${filelines}'a\### TouchUSB Configuration Begin ###\
Section "InputDevice"\
    Identifier  "kt"\
    Driver 	       "evtouch"\
    Option 	       "Device" "/dev/input/ktusb"\
    Option 	       "DeviceName"	"KTUSB"\
    Option 	       "MinX"	        "1932"\
    Option	       "MinY"           "862"\
    Option 	       "MaxX"	        "3378"\
    Option	       "MaxY"           "1914"\
    Option             "MoveLimit"      "10"\
    Option 	       "ReportingMode"	"Raw"\
    Option	       "Emulate3Buttons"\
    Option	       "Emulate3Timeout" "50"\
    Option 	       "SendCoreEvents" "On"\
EndSection \
### TouchUSB Configuration End ###' $PATH_XServerConfig

cp -f "$INSTALL_PATH"/KTcalibrate /etc/ktusb
cp -f "$INSTALL_PATH"/uninstall.sh /etc/ktusb
cp -f "$INSTALL_PATH"/readme.txt /etc/ktusb
chmod 777 /etc/ktusb/*
cp -f "$INSTALL_PATH"/69-touchscreen.rules /etc/udev/rules.d
chmod 777 /etc/udev/rules.d/69-touchscreen.rules

echo
echo "Touch Driver has Installed."
echo
echo "Calibration tools are in the directory /etc/ktusb"
echo "you can copy them to your desktop."

choice=" "
while [ "$choice" != "y" ]; do
echo
echo -n "Do you want to Reboot now? (y/n):"
read choice
echo
case $choice in
      y|Y) echo 'Rebooting...'
           reboot
           echo;;
      n|N) echo 'It is recommaned to reboot after driver installed'
           echo
           break;;
      *) ;;
esac
done
